==> blesta-5.10.2.zip: blesta/components/modules/solusvm/language/zh_cn/solusvm.php <==
<?php
/**
 * Solusvm
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Solusvm.tab_actions.status_offline'] = '离线';
$lang['Solusvm.tab_client_ips.cancel'] = '取消';
$lang['Solusvm.tab_client_ips.remove_ip'] = '删除 IP';
$lang['Solusvm.tab_client_ips.confirm_remove_ip'] = '您确定要永久删除此 IP 地址吗？';
$lang['Solusvm.tab_client_ips.heading_remove_ip'] = '删除 IP %1$s';
$lang['Solusvm.tab_client_ips.primary_ip'] = '主 IP 地址';
$lang['Solusvm.tab_client_ips.heading_extra'] = '额外的 IP 地址';
$lang['Solusvm.tab_ips.confirm_remove'] = '您确定要永久删除此 IP 地址吗？';
$lang['Solusvm.tab_ips.option_remove'] = '删除 IP';
$lang['Solusvm.tab_ips.heading_options'] = '选项';
$lang['Solusvm.tab_ips.heading_ip'] = 'IP 地址';
$lang['Solusvm.tab_ips.heading_extra_ips'] = '额外的 IP 地址';
$lang['Solusvm.tab_ips.primary_ip'] = '主 IP 地址：%1$s';
$lang['Solusvm.tab_ips.heading_ips'] = 'IP 地址';
$lang['Solusvm.tab_client_console.vnc_password'] = 'VNC 密码';
$lang['Solusvm.tab_client_console.console_password'] = '控制台密码';
$lang['Solusvm.tab_client_console.console_username'] = '控制台用户名';
$lang['Solusvm.tab_client_console.heading_console'] = '控制台';
$lang['Solusvm.tab_console.vnc_password'] = 'VNC 密码：';
$lang['Solusvm.tab_console.vnc_port'] = 'VNC 端口：';
$lang['Solusvm.tab_console.vnc_ip'] = 'VNC 主机：';
$lang['Solusvm.tab_console.console_password'] = '控制台密码：';
$lang['Solusvm.tab_console.console_username'] = '控制台用户名：';
$lang['Solusvm.tab_console.heading_console'] = '控制台';
$lang['Solusvm.tab_client_stats.heading_graphs'] = '图表';
$lang['Solusvm.tab_client_stats.usage'] = '(%1$s/%2$s)';
$lang['Solusvm.tab_client_stats.space'] = '磁盘空间';
$lang['Solusvm.tab_client_stats.memory'] = '内存';
$lang['Solusvm.tab_client_stats.bandwidth'] = '带宽';
$lang['Solusvm.tab_client_stats.heading_stats'] = '统计资料';
$lang['Solusvm.tab_stats.heading_graphs'] = '图表';
$lang['Solusvm.tab_status.no_results'] = '目前尚无统计数据。';
$lang['Solusvm.tab_stats.space_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.space_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.space'] = '磁盘空间：';
$lang['Solusvm.tab_stats.memory_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.memory_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.memory'] = '内存';
$lang['Solusvm.tab_stats.bandwidth_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.bandwidth_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.bandwidth'] = '带宽：';
$lang['Solusvm.tab_stats.heading_stats'] = '统计资料';
$lang['Solusvm.tab_client_actions.text_generate_password'] = '生成密码';
$lang['Solusvm.tab_client_actions.field_password_submit'] = '更改密码';
$lang['Solusvm.tab_client_actions.field_confirm_password'] = '确认密码';
$lang['Solusvm.tab_client_actions.field_password'] = '新的根密码';
$lang['Solusvm.tab_client_actions.heading_password'] = '更改密码';
$lang['Solusvm.tab_client_actions.field_hostname_submit'] = '更改主机名';
$lang['Solusvm.tab_client_actions.field_hostname'] = '主机名';
$lang['Solusvm.tab_client_actions.text_hostname_reboot'] = '对主机名的更改只有在服务器重启后才会生效。';
$lang['Solusvm.tab_client_actions.heading_hostname'] = '更改主机名';
$lang['Solusvm.tab_client_actions.field_reinstall_submit'] = '重新安装';
$lang['Solusvm.tab_client_actions.field_confirm'] = '我知道重新安装后，服务器上的所有数据将被永久删除，所选模板将被安装。';
$lang['Solusvm.tab_client_actions.field_template'] = '模板';
$lang['Solusvm.tab_client_actions.heading_reinstall'] = '重新安装';
$lang['Solusvm.tab_client_actions.status_disabled'] = '残疾';
$lang['Solusvm.tab_client_actions.status_offline'] = '离线';
$lang['Solusvm.tab_client_actions.status_online'] = '在线';
$lang['Solusvm.tab_client_actions.heading_node'] = '节点';
$lang['Solusvm.tab_client_actions.heading_server_status'] = '服务器状态';
$lang['Solusvm.tab_client_actions.heading_actions'] = '行动';
$lang['Solusvm.tab_actions.text_generate_password'] = '生成密码';
$lang['Solusvm.tab_actions.field_password_submit'] = '更改密码';
$lang['Solusvm.tab_actions.field_confirm_password'] = '确认密码';
$lang['Solusvm.tab_actions.field_password'] = '新的根密码';
$lang['Solusvm.tab_actions.heading_password'] = '更改密码';
$lang['Solusvm.tab_actions.field_hostname_submit'] = '更改主机名';
$lang['Solusvm.tab_actions.field_hostname'] = '主机名';
$lang['Solusvm.tab_actions.text_hostname_reboot'] = '对主机名的更改只有在服务器重启后才会生效。';
$lang['Solusvm.tab_actions.heading_hostname'] = '更改主机名';
$lang['Solusvm.tab_actions.field_reinstall_submit'] = '重新安装';
$lang['Solusvm.tab_actions.field_confirm'] = '我知道重新安装后，服务器上的所有数据将被永久删除，所选模板将被安装。';
$lang['Solusvm.tab_actions.field_template'] = '模板';
$lang['Solusvm.tab_actions.heading_reinstall'] = '重新安装';
$lang['Solusvm.tab_actions.node'] = '节点： %1$s';
$lang['Solusvm.tab_actions.server_status'] = '服务器状态';
$lang['Solusvm.tab_actions.status_disabled'] = '残疾';
$lang['Solusvm.tab_actions.status_online'] = '在线';
$lang['Solusvm.tab_actions.heading_actions'] = '行动';
$lang['Solusvm.tab_ips'] = 'IP 地址';
$lang['Solusvm.tab_console'] = '控制台';
$lang['Solusvm.tab_stats'] = '统计数据';
$lang['Solusvm.tab_actions'] = '服务器行动';
$lang['Solusvm.service_info.solusvm_main_ip_address'] = '主 IP 地址';
$lang['Solusvm.service_field.tooltip.solusvm_vserver_id'] = '虚拟服务器 ID 指定该服务将连接的 SolusVM VPS。更改此值只会在本地影响此服务。';
$lang['Solusvm.service_field.solusvm_vserver_id'] = '虚拟服务器 ID';
$lang['Solusvm.service_field.solusvm_template'] = '模板';
$lang['Solusvm.service_field.solusvm_hostname'] = '主机名';
$lang['Solusvm.package_fields.node_group'] = '节点组';
$lang['Solusvm.package_fields.set_node_group'] = '指定节点组';
$lang['Solusvm.package_fields.set_node'] = '分配一组节点';
$lang['Solusvm.package_fields.available_nodes'] = '可用节点';
$lang['Solusvm.package_fields.assigned_nodes'] = '分配节点';
$lang['Solusvm.package_fields.plan'] = '计划';
$lang['Solusvm.package_fields.client_set_template'] = '让客户设置模板';
$lang['Solusvm.package_fields.admin_set_template'] = '选择模板';
$lang['Solusvm.package_fields.template'] = '模板';
$lang['Solusvm.package_fields.type'] = '类型';
$lang['Solusvm.package_fields.tooltip.total_base_ip_addresses'] = '输入要包含在新服务中的 IP 地址总数。必须至少有一个，且 IP 不能删除。';
$lang['Solusvm.package_fields.total_base_ip_addresses'] = '基本 IP 地址数量';
$lang['Solusvm.edit_row.add_btn'] = '更新服务器';
$lang['Solusvm.edit_row.basic_title'] = '基本设置';
$lang['Solusvm.edit_row.box_title'] = '编辑 SolusVM 服务器';
$lang['Solusvm.add_row.add_btn'] = '添加服务器';
$lang['Solusvm.add_row.basic_title'] = '基本设置';
$lang['Solusvm.add_row.box_title'] = '添加 SolusVM 服务器';
$lang['Solusvm.types.kvm'] = 'KVM';
$lang['Solusvm.types.xen_hvm'] = 'Xen HVM';
$lang['Solusvm.types.xen'] = '氙气';
$lang['Solusvm.types.openvz'] = 'OpenVZ';
$lang['Solusvm.row_meta.default_port'] = '5656';
$lang['Solusvm.row_meta.port'] = 'SSL 端口号';
$lang['Solusvm.row_meta.host'] = '主机名';
$lang['Solusvm.row_meta.key'] = '钥匙';
$lang['Solusvm.row_meta.user_id'] = '用户 ID';
$lang['Solusvm.row_meta.server_name'] = '服务器标签';
$lang['Solusvm.order_options.first'] = '第一个非满员服务器';
$lang['Solusvm.manage.module_groups_no_results'] = '没有服务器组。';
$lang['Solusvm.manage.module_rows_no_results'] = '没有服务器。';
$lang['Solusvm.manage.module_groups.confirm_delete'] = '您确定要删除此服务器组吗？';
$lang['Solusvm.manage.module_rows.confirm_delete'] = '您确定要删除这个服务器吗？';
$lang['Solusvm.manage.module_groups.delete'] = '删除';
$lang['Solusvm.manage.module_rows.delete'] = '删除';
$lang['Solusvm.manage.module_groups.edit'] = '编辑';
$lang['Solusvm.manage.module_rows.edit'] = '编辑';
$lang['Solusvm.manage.module_groups_heading.options'] = '选项';
$lang['Solusvm.manage.module_groups_heading.servers'] = '服务器数量';
$lang['Solusvm.manage.module_groups_heading.name'] = '组名';
$lang['Solusvm.manage.module_rows_heading.options'] = '选项';
$lang['Solusvm.manage.module_rows_heading.host'] = '主机名';
$lang['Solusvm.manage.module_rows_heading.server_label'] = '服务器标签';
$lang['Solusvm.manage.module_groups_title'] = 'SolusVM 主服务器组';
$lang['Solusvm.manage.module_rows_title'] = 'SolusVM 主服务器';
$lang['Solusvm.add_module_group'] = '添加服务器组';
$lang['Solusvm.add_module_row'] = '添加服务器';
$lang['Solusvm.module_group'] = 'SolusVM 主机组';
$lang['Solusvm.module_row_plural'] = '服务器';
$lang['Solusvm.module_row'] = 'SolusVM 主服务器';
$lang['Solusvm.description'] = 'Solus Virtual Manager (SolusVM) 是一款功能强大的基于图形用户界面的 VPS 管理系统，完全支持 OpenVZ、Linux KVM、Xen Paravirtualization 和 Xen HVM。';
$lang['Solusvm.!actions.boot'] = '靴子';
$lang['Solusvm.!percent.used'] = '%1$s%';
$lang['Solusvm.!bytes.value'] = '%1$s%2$s';
$lang['Solusvm.please_select'] = '-- 请选择';
$lang['Solusvm.!success.reinstall'] = '服务器正在重新安装。';
$lang['Solusvm.!success.hostname'] = '已成功更改主机名。';
$lang['Solusvm.!success.password'] = '密码已成功更改。';
$lang['Solusvm.!success.shutdown'] = '服务器现已关闭。';
$lang['Solusvm.!success.reboot'] = '服务器正在重启。';
$lang['Solusvm.!success.boot'] = '服务器正在启动。';
$lang['Solusvm.!error.configoptions[customextraip].valid'] = '在未指定要删除哪些 IP 的情况下，不能减少额外 IP 的数量。';
$lang['Solusvm.!error.solusvm_vserver_id.format'] = '虚拟服务器 ID 必须是整数。';
$lang['Solusvm.!error.solusvm_root_password.matches'] = '根密码不匹配。';
$lang['Solusvm.!error.solusvm_root_password.length'] = '根密码长度必须至少为 6 个字符。';
$lang['Solusvm.!error.api.confirm.valid'] = '您必须确认了解重新安装操作，才能执行模板重新安装。';
$lang['Solusvm.!error.api.template.valid'] = '所选模板无效。';
$lang['Solusvm.!error.create_client.failed'] = '发生内部错误，无法创建客户帐户。';
$lang['Solusvm.!error.solusvm_template.valid'] = '请选择有效模板。';
$lang['Solusvm.!error.solusvm_hostname.format'] = '请输入有效的完全合格域名（如 host.domain.com）作为主机名。';
$lang['Solusvm.!error.api.internal'] = '发生内部错误，或服务器未响应请求。';
$lang['Solusvm.!error.meta[total_base_ip_addresses].format'] = '请仅输入 IP 地址数量的数字，数值为 1 或更多。';
$lang['Solusvm.!error.meta[template].empty'] = '请选择一个模板。';
$lang['Solusvm.!error.meta[set_template].format'] = '请设置是选择模板还是允许客户设置模板。';
$lang['Solusvm.!error.meta[plan].empty'] = '请选择一个计划。';
$lang['Solusvm.!error.meta[nodes].empty'] = '请至少选择一个节点或节点组。';
$lang['Solusvm.!error.meta[type].valid'] = '请选择有效的虚拟化类型。';
$lang['Solusvm.!error.port.format'] = '请输入有效的端口号。';
$lang['Solusvm.!error.host.format'] = '主机名似乎无效。';
$lang['Solusvm.!error.key.empty'] = '请输入密钥。';
$lang['Solusvm.!error.user_id.empty'] = '请输入用户 ID。';
$lang['Solusvm.!error.server_name.empty'] = '请输入服务器标签。';
$lang['SolusVM.!error.simplexml_required'] = '该模块需要使用 simplexml 扩展名。';
$lang['Solusvm.!actions.password'] = '更改密码';
$lang['Solusvm.!actions.hostname'] = '更改主机名';
$lang['Solusvm.!actions.reinstall'] = '重新安装';
$lang['Solusvm.!actions.shutdown'] = '关闭';
$lang['Solusvm.!actions.reboot'] = '重新启动';
$lang['Solusvm.name'] = 'SolusVM';

==> blesta-5.11.4.zip: blesta/components/modules/solusvm/language/zh_cn/solusvm.php <==
<?php
/**
 * Solusvm
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Solusvm.tab_actions.status_offline'] = '离线';
$lang['Solusvm.tab_client_ips.cancel'] = '取消';
$lang['Solusvm.tab_client_ips.remove_ip'] = '删除 IP';
$lang['Solusvm.tab_client_ips.confirm_remove_ip'] = '您确定要永久删除此 IP 地址吗？';
$lang['Solusvm.tab_client_ips.heading_remove_ip'] = '删除 IP %1$s';
$lang['Solusvm.tab_client_ips.primary_ip'] = '主 IP 地址';
$lang['Solusvm.tab_client_ips.heading_extra'] = '额外的 IP 地址';
$lang['Solusvm.tab_ips.confirm_remove'] = '您确定要永久删除此 IP 地址吗？';
$lang['Solusvm.tab_ips.option_remove'] = '删除 IP';
$lang['Solusvm.tab_ips.heading_options'] = '选项';
$lang['Solusvm.tab_ips.heading_ip'] = 'IP 地址';
$lang['Solusvm.tab_ips.heading_extra_ips'] = '额外的 IP 地址';
$lang['Solusvm.tab_ips.primary_ip'] = '主 IP 地址：%1$s';
$lang['Solusvm.tab_ips.heading_ips'] = 'IP 地址';
$lang['Solusvm.tab_client_console.vnc_password'] = 'VNC 密码';
$lang['Solusvm.tab_client_console.console_password'] = '控制台密码';
$lang['Solusvm.tab_client_console.console_username'] = '控制台用户名';
$lang['Solusvm.tab_client_console.heading_console'] = '控制台';
$lang['Solusvm.tab_console.vnc_password'] = 'VNC 密码：';
$lang['Solusvm.tab_console.vnc_port'] = 'VNC 端口：';
$lang['Solusvm.tab_console.vnc_ip'] = 'VNC 主机：';
$lang['Solusvm.tab_console.console_password'] = '控制台密码：';
$lang['Solusvm.tab_console.console_username'] = '控制台用户名：';
$lang['Solusvm.tab_console.heading_console'] = '控制台';
$lang['Solusvm.tab_client_stats.heading_graphs'] = '图表';
$lang['Solusvm.tab_client_stats.usage'] = '(%1$s/%2$s)';
$lang['Solusvm.tab_client_stats.space'] = '磁盘空间';
$lang['Solusvm.tab_client_stats.memory'] = '内存';
$lang['Solusvm.tab_client_stats.bandwidth'] = '带宽';
$lang['Solusvm.tab_client_stats.heading_stats'] = '统计资料';
$lang['Solusvm.tab_stats.heading_graphs'] = '图表';
$lang['Solusvm.tab_status.no_results'] = '目前尚无统计数据。';
$lang['Solusvm.tab_stats.space_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.space_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.space'] = '磁盘空间：';
$lang['Solusvm.tab_stats.memory_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.memory_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.memory'] = '内存';
$lang['Solusvm.tab_stats.bandwidth_percent_available'] = '(%1$s%%)';
$lang['Solusvm.tab_stats.bandwidth_stats'] = '%1$s/%2$s';
$lang['Solusvm.tab_stats.bandwidth'] = '带宽：';
$lang['Solusvm.tab_stats.heading_stats'] = '统计资料';
$lang['Solusvm.tab_client_actions.text_generate_password'] = '生成密码';
$lang['Solusvm.tab_client_actions.field_password_submit'] = '更改密码';
$lang['Solusvm.tab_client_actions.field_confirm_password'] = '确认密码';
$lang['Solusvm.tab_client_actions.field_password'] = '新的根密码';
$lang['Solusvm.tab_client_actions.heading_password'] = '更改密码';
$lang['Solusvm.tab_client_actions.field_hostname_submit'] = '更改主机名';
$lang['Solusvm.tab_client_actions.field_hostname'] = '主机名';
$lang['Solusvm.tab_client_actions.text_hostname_reboot'] = '对主机名的更改只有在服务器重启后才会生效。';
$lang['Solusvm.tab_client_actions.heading_hostname'] = '更改主机名';
$lang['Solusvm.tab_client_actions.field_reinstall_submit'] = '重新安装';
$lang['Solusvm.tab_client_actions.field_confirm'] = '我知道重新安装后，服务器上的所有数据将被永久删除，所选模板将被安装。';
$lang['Solusvm.tab_client_actions.field_template'] = '模板';
$lang['Solusvm.tab_client_actions.heading_reinstall'] = '重新安装';
$lang['Solusvm.tab_client_actions.status_disabled'] = '残疾';
$lang['Solusvm.tab_client_actions.status_offline'] = '离线';
$lang['Solusvm.tab_client_actions.status_online'] = '在线';
$lang['Solusvm.tab_client_actions.heading_node'] = '节点';
$lang['Solusvm.tab_client_actions.heading_server_status'] = '服务器状态';
$lang['Solusvm.tab_client_actions.heading_actions'] = '行动';
$lang['Solusvm.tab_actions.text_generate_password'] = '生成密码';
$lang['Solusvm.tab_actions.field_password_submit'] = '更改密码';
$lang['Solusvm.tab_actions.field_confirm_password'] = '确认密码';
$lang['Solusvm.tab_actions.field_password'] = '新的根密码';
$lang['Solusvm.tab_actions.heading_password'] = '更改密码';
$lang['Solusvm.tab_actions.field_hostname_submit'] = '更改主机名';
$lang['Solusvm.tab_actions.field_hostname'] = '主机名';
$lang['Solusvm.tab_actions.text_hostname_reboot'] = '对主机名的更改只有在服务器重启后才会生效。';
$lang['Solusvm.tab_actions.heading_hostname'] = '更改主机名';
$lang['Solusvm.tab_actions.field_reinstall_submit'] = '重新安装';
$lang['Solusvm.tab_actions.field_confirm'] = '我知道重新安装后，服务器上的所有数据将被永久删除，所选模板将被安装。';
$lang['Solusvm.tab_actions.field_template'] = '模板';
$lang['Solusvm.tab_actions.heading_reinstall'] = '重新安装';
$lang['Solusvm.tab_actions.node'] = '节点： %1$s';
$lang['Solusvm.tab_actions.server_status'] = '服务器状态';
$lang['Solusvm.tab_actions.status_disabled'] = '残疾';
$lang['Solusvm.tab_actions.status_online'] = '在线';
$lang['Solusvm.tab_actions.heading_actions'] = '行动';
$lang['Solusvm.tab_ips'] = 'IP 地址';
$lang['Solusvm.tab_console'] = '控制台';
$lang['Solusvm.tab_stats'] = '统计数据';
$lang['Solusvm.tab_actions'] = '服务器行动';
$lang['Solusvm.service_info.solusvm_main_ip_address'] = '主 IP 地址';
$lang['Solusvm.service_field.tooltip.solusvm_vserver_id'] = '虚拟服务器 ID 指定该服务将连接的 SolusVM VPS。更改此值只会在本地影响此服务。';
$lang['Solusvm.service_field.solusvm_vserver_id'] = '虚拟服务器 ID';
$lang['Solusvm.service_field.solusvm_template'] = '模板';
$lang['Solusvm.service_field.solusvm_hostname'] = '主机名';
$lang['Solusvm.package_fields.node_group'] = '节点组';
$lang['Solusvm.package_fields.set_node_group'] = '指定节点组';
$lang['Solusvm.package_fields.set_node'] = '分配一组节点';
$lang['Solusvm.package_fields.available_nodes'] = '可用节点';
$lang['Solusvm.package_fields.assigned_nodes'] = '分配节点';
$lang['Solusvm.package_fields.plan'] = '计划';
$lang['Solusvm.package_fields.client_set_template'] = '让客户设置模板';
$lang['Solusvm.package_fields.admin_set_template'] = '选择模板';
$lang['Solusvm.package_fields.template'] = '模板';
$lang['Solusvm.package_fields.type'] = '类型';
$lang['Solusvm.package_fields.tooltip.total_base_ip_addresses'] = '输入要包含在新服务中的 IP 地址总数。必须至少有一个，且 IP 不能删除。';
$lang['Solusvm.package_fields.total_base_ip_addresses'] = '基本 IP 地址数量';
$lang['Solusvm.edit_row.add_btn'] = '更新服务器';
$lang['Solusvm.edit_row.basic_title'] = '基本设置';
$lang['Solusvm.edit_row.box_title'] = '编辑 SolusVM 服务器';
$lang['Solusvm.add_row.add_btn'] = '添加服务器';
$lang['Solusvm.add_row.basic_title'] = '基本设置';
$lang['Solusvm.add_row.box_title'] = '添加 SolusVM 服务器';
$lang['Solusvm.types.kvm'] = 'KVM';
$lang['Solusvm.types.xen_hvm'] = 'Xen HVM';
$lang['Solusvm.types.xen'] = '氙气';
$lang['Solusvm.types.openvz'] = 'OpenVZ';
$lang['Solusvm.row_meta.default_port'] = '5656';
$lang['Solusvm.row_meta.port'] = 'SSL 端口号';
$lang['Solusvm.row_meta.host'] = '主机名';
$lang['Solusvm.row_meta.key'] = '钥匙';
$lang['Solusvm.row_meta.user_id'] = '用户 ID';
$lang['Solusvm.row_meta.server_name'] = '服务器标签';
$lang['Solusvm.order_options.first'] = '第一个非满员服务器';
$lang['Solusvm.manage.module_groups_no_results'] = '没有服务器组。';
$lang['Solusvm.manage.module_rows_no_results'] = '没有服务器。';
$lang['Solusvm.manage.module_groups.confirm_delete'] = '您确定要删除此服务器组吗？';
$lang['Solusvm.manage.module_rows.confirm_delete'] = '您确定要删除这个服务器吗？';
$lang['Solusvm.manage.module_groups.delete'] = '删除';
$lang['Solusvm.manage.module_rows.delete'] = '删除';
$lang['Solusvm.manage.module_groups.edit'] = '编辑';
$lang['Solusvm.manage.module_rows.edit'] = '编辑';
$lang['Solusvm.manage.module_groups_heading.options'] = '选项';
$lang['Solusvm.manage.module_groups_heading.servers'] = '服务器数量';
$lang['Solusvm.manage.module_groups_heading.name'] = '组名';
$lang['Solusvm.manage.module_rows_heading.options'] = '选项';
$lang['Solusvm.manage.module_rows_heading.host'] = '主机名';
$lang['Solusvm.manage.module_rows_heading.server_label'] = '服务器标签';
$lang['Solusvm.manage.module_groups_title'] = 'SolusVM 主服务器组';
$lang['Solusvm.manage.module_rows_title'] = 'SolusVM 主服务器';
$lang['Solusvm.add_module_group'] = '添加服务器组';
$lang['Solusvm.add_module_row'] = '添加服务器';
$lang['Solusvm.module_group'] = 'SolusVM 主机组';
$lang['Solusvm.module_row_plural'] = '服务器';
$lang['Solusvm.module_row'] = 'SolusVM 主服务器';
$lang['Solusvm.description'] = 'Solus Virtual Manager (SolusVM) 是一款功能强大的基于图形用户界面的 VPS 管理系统，完全支持 OpenVZ、Linux KVM、Xen Paravirtualization 和 Xen HVM。';
$lang['Solusvm.!actions.boot'] = '靴子';
$lang['Solusvm.!percent.used'] = '%1$s';
$lang['Solusvm.!bytes.value'] = '%1$s%2$s';
$lang['Solusvm.please_select'] = '-- 请选择';
$lang['Solusvm.!success.reinstall'] = '服务器正在重新安装。';
$lang['Solusvm.!success.hostname'] = '已成功更改主机名。';
$lang['Solusvm.!success.password'] = '密码已成功更改。';
$lang['Solusvm.!success.shutdown'] = '服务器现已关闭。';
$lang['Solusvm.!success.reboot'] = '服务器正在重启。';
$lang['Solusvm.!success.boot'] = '服务器正在启动。';
$lang['Solusvm.!error.configoptions[customextraip].valid'] = '在未指定要删除哪些 IP 的情况下，不能减少额外 IP 的数量。';
$lang['Solusvm.!error.solusvm_vserver_id.format'] = '虚拟服务器 ID 必须是整数。';
$lang['Solusvm.!error.solusvm_root_password.matches'] = '根密码不匹配。';
$lang['Solusvm.!error.solusvm_root_password.length'] = '根密码长度必须至少为 6 个字符。';
$lang['Solusvm.!error.api.confirm.valid'] = '您必须确认了解重新安装操作，才能执行模板重新安装。';
$lang['Solusvm.!error.api.template.valid'] = '所选模板无效。';
$lang['Solusvm.!error.create_client.failed'] = '发生内部错误，无法创建客户帐户。';
$lang['Solusvm.!error.solusvm_template.valid'] = '请选择有效模板。';
$lang['Solusvm.!error.solusvm_hostname.format'] = '请输入有效的完全合格域名（如 host.domain.com）作为主机名。';
$lang['Solusvm.!error.api.internal'] = '发生内部错误，或服务器未响应请求。';
$lang['Solusvm.!error.meta[total_base_ip_addresses].format'] = '请仅输入 IP 地址数量的数字，数值为 1 或更多。';
$lang['Solusvm.!error.meta[template].empty'] = '请选择一个模板。';
$lang['Solusvm.!error.meta[set_template].format'] = '请设置是选择模板还是允许客户设置模板。';
$lang['Solusvm.!error.meta[plan].empty'] = '请选择一个计划。';
$lang['Solusvm.!error.meta[nodes].empty'] = '请至少选择一个节点或节点组。';
$lang['Solusvm.!error.meta[type].valid'] = '请选择有效的虚拟化类型。';
$lang['Solusvm.!error.port.format'] = '请输入有效的端口号。';
$lang['Solusvm.!error.host.format'] = '主机名似乎无效。';
$lang['Solusvm.!error.key.empty'] = '请输入密钥。';
$lang['Solusvm.!error.user_id.empty'] = '请输入用户 ID。';
$lang['Solusvm.!error.server_name.empty'] = '请输入服务器标签。';
$lang['SolusVM.!error.simplexml_required'] = '该模块需要使用 simplexml 扩展名。';
$lang['Solusvm.!actions.password'] = '更改密码';
$lang['Solusvm.!actions.hostname'] = '更改主机名';
$lang['Solusvm.!actions.reinstall'] = '重新安装';
$lang['Solusvm.!actions.shutdown'] = '关闭';
$lang['Solusvm.!actions.reboot'] = '重新启动';
$lang['Solusvm.name'] = 'SolusVM';
